.. _userguide:


Reference guide
---------------

Exporting
^^^^^^^^^^


Using tables
^^^^^^^^^^^^

to write

Using figures
^^^^^^^^^^^^^^

Formatters:

* ``scale``: displays in greyscale normalizing. 
    
    Parameters:
	
	``min_value``,``max_value``
	  to write
	``rgb1``, ``rgb2``
	  to write
	
* ``posneg``: displays the negative part in blue and the positive part in red
	max_value

Attaching data
^^^^^^^^^^^^^^
